
.include "m32def.inc" 

;Sprungbefehle zu Programmteilen, die je nach Interrupt ausgefhrt werden sollen.
.org 0x000				rjmp main			; Reset             


;****************************************************************************
;*Hauptprogramm
;****************************************************************************

.include "lcd-routines.asm"
.include "text_init.asm"
.include "I2C-routines.asm"
.include "calculation_DS1621.asm"

.def temp1 = r16
.def temp2 = r17

.def data = r18

.def TempH = r27
.def TempL = r28

.equ I2C_PIN = PINC
.equ I2C_DDR = DDRC
.equ I2C_Port = PortC

.equ SCL = 0
.equ SDA = 1

.equ DS1621_Write = 0b10011110	
.equ DS1621_Read  = 0b10011111	; control code = 1001, device select bit = xxx, control byte --> 0=write, 1=read

main:

	ldi temp1, low(RAMEND)		;Die Startadresse des Stack (Stapelspeicher) wird festgelegt und der Stackpointer
	out SPL, temp1				;(Stapelzeiger) auf diesen Wert gesetzt. Die weitere Nutzung des Stack bernimmt
	ldi temp1, high(RAMEND)		;der Mikrocontroller selbst.
	out SPH, temp1 

    call lcd_init              	;LC-Display initialisieren
    call lcd_clear             	;Display lschen
	call text_init

	sbi		I2C_DDR,SCL			; SCL als Ausgang
	sbi		I2C_DDR,SDA			; SDA als Ausgang
;	sbi		I2C_Port,SCL
;	sbi		I2C_Port,SDA


	; Start
	rcall	I2C_Start

	; I2C-Adresse senden
	ldi		data,DS1621_Write	
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; Command-Byte zum Anwaehlen des Konfigurations-Register
	ldi		data,0b10101100				; 0xAC
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; das zu schreibende Daten-Byte
	ldi		data,0b00000000				; continuously perform
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; Stop
	rcall	I2C_Stop


	rcall	I2C_Wait
	rcall	I2C_Wait
	rcall	I2C_Wait


	; Start
	rcall	I2C_Start

	; I2C-Adresse senden
	ldi		data,DS1621_Write	
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; Command-Byte zum Starten der Umwandlung
	ldi		data,0b11101110				; 0xEE
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; Stop
	rcall	I2C_Stop


	rcall	I2C_Wait
	rcall	I2C_Wait
	rcall	I2C_Wait



Lese_Temp:
	; Start
	rcall	I2C_Start

	; I2C-Adresse senden
	ldi		data,DS1621_Write	
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; Command-Byte zum Temp. lesen
	ldi		data,0b10101010				;0xAA
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; Start
	rcall	I2C_Start

	; I2C-Adresse senden
	ldi		data,DS1621_Read	
	rcall	I2C_Send
	rcall	I2C_Read_Ack

	; I2C-Daten-Byte lesen = Milli-Sekunden
	rcall	I2C_Read
	rcall	I2C_Send_Ack
	mov		TempH,data

	; I2C-Daten-Byte lesen = Sekunden
	rcall	I2C_Read
	rcall	I2C_Send_no_Ack
	mov		TempL,data			

	; Stop
	rcall	I2C_Stop



	; Ausgabe 
	ldi zeile, 4
	ldi spalte, 11
	call set_cursor

	call calc_DS1621

	call wait_1s


	rjmp	Lese_Temp


wait_1s:
push R25
push R26
push R27
; warte 11058993 Zyklen:
          ldi  R25, $BB
WGLOOP0a:  ldi  R26, $4D
WGLOOP1a:  ldi  R27, $FF
WGLOOP2a:  dec  R27
          brne WGLOOP2a
          dec  R26
          brne WGLOOP1a
          dec  R25
          brne WGLOOP0a
; ----------------------------- 
; warte 6 Zyklen:
          ldi  R25, $02
WGLOOP3a:  dec  R25
          brne WGLOOP3a
; ----------------------------- 
; warte 1 Zyklus:
          nop
; ============================= 
pop R27
pop R26
pop R25
ret                             



